@@ -91,9 +91,8 @@ length.numpy.ndarray <- function(x) {
 array_reshape <- function(x, dim, order = c("C", "F")) {
   np <- import("numpy", convert = FALSE)
   order <- match.arg(order)
-  reshaped <- np$reshape(x, as.integer(dim), order)
+  reshaped <- np$reshape(x, as.integer(dim), order = order)
   if (!is_py_object(x))
     reshaped <- py_to_r(reshaped)
   reshaped
 }
-
