@@ -5,7 +5,7 @@
 #'
 #' Virtual environments are by default located at `~/.virtualenvs` (accessed
 #' with the `virtualenv_root()` function). You can change the default location
-#' by defining the `WORKON_HOME` environment variable.
+#' by defining the `RETICULATE_VIRTUALENV_ROOT` or `WORKON_HOME` environment variables.
 #'
 #' Virtual environments are created from another "starter" or "seed" Python
 #' already installed on the system. Suitable Pythons installed on the system are
@@ -333,6 +333,10 @@ virtualenv_list <- function() {
 #' @rdname virtualenv-tools
 #' @export
 virtualenv_root <- function() {
+  root <- Sys.getenv("RETICULATE_VIRTUALENV_ROOT", NA_character_)
+  if (!is.na(root))
+    return(root)
+
   Sys.getenv("WORKON_HOME", unset = "~/.virtualenvs")
 }
 
